@@ -33,7 +33,7 @@ if __name__ == "__main__":
     p["/usr/share/applications/hildon"] = ["mcalendar.desktop",]
     p["/usr/lib/python2.5/site-packages"] = [
       "mcalendar_framework.py","mcalendar_framework.pyo","mcalendar_framework.pyc",]
-    p["/usr/lib/mcalendar"] = [
+    p["/usr/lib/mcalendar"] = [ "mcalendar.py",
       "agenda_view.py","agenda_view.pyo",
       "mcalendar_sync.pyc","mcalendar_sync.pyo","mcalendar_sync.py",
       "mcalendar_ui.py","mcalendar_ui.pyo",#"mcalendar_ui.pyc",
@@ -52,7 +52,12 @@ if __name__ == "__main__":
       "ui/favorite.png","ui/next.png","ui/week.png",
       "ui/help.png","ui/people.png",]
 
+    p.postinstall = """#!/bin/sh
+chmod +x /usr/bin/mcalendar.launch
+chmod +x /usr/lib/mcalendar/mcalendar.py
+chmod +x /usr/lib/mcalendar/mcalendar_sync.py"""
+
     print p
-    r = p.generate("0.5.5","2",changelog=" * Change on framework to work with HomeCalendar",tar=True,dsc=True,changes=True,build=False,src=True)
-    print re
-#scp *0.5.4-1* khertan@garage.maemo.org:/var/www/extras-devel/incoming-builder/diablo
\ No newline at end of file
+    r = p.generate("0.5.7","3",changelog=" * Fix for python launcher",tar=True,dsc=True,changes=True,build=False,src=True)
+    print r
+#scp *0.5.7-3* khertan@garage.maemo.org:/var/www/extras-devel/incoming-builder/diablo
\ No newline at end of file
