@@ -42,7 +42,7 @@ class mCalendar(object):
 
   __pretty_app_name__ = "mCalendar"
   __app_name__ = "mcalendar"
-  __version__ = "0.5.5"
+  __version__ = "0.5.7"
 
   _glade_files = [
 #    'ui/mcalendar.glade',
@@ -62,6 +62,7 @@ class mCalendar(object):
 #     gtk.main_quit()
       return
 
+
     #Get the buffer associated with the number display
     self._window = self._widgetTree.get_widget("MainWin")
 
@@ -71,6 +72,7 @@ class mCalendar(object):
       print "Hildon installed but glade file not updated to work with hildon"
   #    hildon = None
     elif IS_MAEMO == True:
+      gtk.set_application_name(mCalendar.__pretty_app_name__)
       self._app = hildon.Program()
       self._window = hildon.Window()
 #      self._window.set_border_width(0)
@@ -305,6 +307,8 @@ class mCalendar(object):
   def _win_closebox(self,widget,data):
     if (self._current_virtual_win == 0):
       self._window.destroy()
+      gobject.source_remove(self.timer)
+      self.timer = None
       gtk.main_quit()
       return False
     else:
@@ -1283,7 +1287,7 @@ class mCalendar(object):
             else:
               start_time = datetime.datetime.strptime(model.get_value(selection_iter, 1).split(' - ')[0],self._prefs_get_datetime_format())
               end_time = datetime.datetime.strptime(model.get_value(selection_iter, 1).split(' - ')[1],self._prefs_get_datetime_format())
-            
+
           else:
             print 'debug 9'
             start_time = self.get_start_of_day()
